pub struct Http01Handler { /* private fields */ }Expand description
Handler for HTTP-01 ACME challenges.
Reads challenge tokens from a shared map that is populated by the ACME
issuance flow. This handler should be registered on the router at
/.well-known/acme-challenge/{token}.